@@ -31,6 +31,11 @@ from .generation.hugging_face.core import (  # noqa: F401
     HuggingFaceXLMGenerator,
     HuggingFaceXLNetGenerator,
 )
+from .generation.pgt.core import (  # noqa: F401
+    PGTCoherenceChecker,
+    PGTEditor,
+    PGTGenerator,
+)
 from .generation.polymer_blocks.core import PolymerBlocksGenerator  # noqa: F401
 from .prediction.paccmann.core import PaccMann  # noqa: F401
 from .prediction.topics_zero_shot.core import TopicsPredictor  # noqa: F401
